[Pkg-mozext-commits] [adblock-plus-element-hiding-helper] 186/483: Updated build script dummies to use new buildtools repository

David Prévot taffit at moszumanska.debian.org
Thu Jan 22 21:41:39 UTC 2015


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to branch master
in repository adblock-plus-element-hiding-helper.

commit a5b6f0009a345ee276412d67fc849ff976e2ff12
Author: Wladimir Palant <trev at adblockplus.org>
Date:   Mon Nov 16 08:53:33 2009 +0100

    Updated build script dummies to use new buildtools repository
---
 create_xpi.pl           | 4 ++--
 make_devbuild.pl        | 4 ++--
 make_release.pl         | 4 ++--
 setupTestEnvironment.pl | 4 ++--
 4 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/create_xpi.pl b/create_xpi.pl
index f251151..de0cd30 100644
--- a/create_xpi.pl
+++ b/create_xpi.pl
@@ -1,8 +1,8 @@
 #!/usr/bin/perl
 
 # This is a dummy, its purpose is to call a script with the same name in the parent directory
 
 $0 =~ s/(.*[\\\/])//g;
 chdir($1) if $1;
-do "../$0";
+do "buildtools/$0";
 die $@ if $@;
@@ -1,8 +1,8 @@
 #!/usr/bin/perl
 
-# This is a dummy, its purpose is to call a script with the same name in the parent directory
+# This is a dummy, its purpose is to call a script with the same name in the buildtools repository
 
 $0 =~ s/(.*[\\\/])//g;
diff --git a/make_devbuild.pl b/make_devbuild.pl
index f251151..de0cd30 100644
--- a/make_devbuild.pl
+++ b/make_devbuild.pl
@@ -1,8 +1,8 @@
 #!/usr/bin/perl
 
 # This is a dummy, its purpose is to call a script with the same name in the parent directory
 
 $0 =~ s/(.*[\\\/])//g;
 chdir($1) if $1;
-do "../$0";
+do "buildtools/$0";
 die $@ if $@;
@@ -1,8 +1,8 @@
 #!/usr/bin/perl
 
-# This is a dummy, its purpose is to call a script with the same name in the parent directory
+# This is a dummy, its purpose is to call a script with the same name in the buildtools repository
 
 $0 =~ s/(.*[\\\/])//g;
diff --git a/make_release.pl b/make_release.pl
index 532d425..e438704 100644
--- a/make_release.pl
+++ b/make_release.pl
@@ -1,10 +1,10 @@
 #!/usr/bin/perl
 
 # This is a dummy, its purpose is to call a script with the same name in the parent directory
 
 our $BRANCH_NAME = "ELEMENT_HIDING_HELPER";
 
 $0 =~ s/(.*[\\\/])//g;
 chdir($1) if $1;
-do "../$0";
+do "buildtools/$0";
 die $@ if $@;
@@ -1,10 +1,10 @@
 #!/usr/bin/perl
 
-# This is a dummy, its purpose is to call a script with the same name in the parent directory
+# This is a dummy, its purpose is to call a script with the same name in the buildtools repository
 
 our $BRANCH_NAME = "ELEMENT_HIDING_HELPER";
diff --git a/setupTestEnvironment.pl b/setupTestEnvironment.pl
index f251151..de0cd30 100644
--- a/setupTestEnvironment.pl
+++ b/setupTestEnvironment.pl
@@ -1,8 +1,8 @@
 #!/usr/bin/perl
 
 # This is a dummy, its purpose is to call a script with the same name in the parent directory
 
 $0 =~ s/(.*[\\\/])//g;
 chdir($1) if $1;
-do "../$0";
+do "buildtools/$0";
 die $@ if $@;
@@ -1,8 +1,8 @@
 #!/usr/bin/perl
 
-# This is a dummy, its purpose is to call a script with the same name in the parent directory
+# This is a dummy, its purpose is to call a script with the same name in the buildtools repository
 
 $0 =~ s/(.*[\\\/])//g;

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-mozext/adblock-plus-element-hiding-helper.git



More information about the Pkg-mozext-commits mailing list